"""
CONSTANT DIRECTORY NAMES
"""

APP_DIR_NAME = "app"
RESOURCES_DIR_NAME = "resources"
WRITABLE_DIR_NAME = "writable"
FIXTURES_DIR_NAME = "fixtures"

DEFAULT_FIXTURE_DIR_NAME = "base"
PROD_FIXTURE_DIR_NAME = "prod"
TEST_FIXTURE_DIR_NAME = "test"

RESOURCE_CONFIG_DIR_NAME = "config"
SETUP_SCRIPTS_DIR_NAME = "setup"
TEST_DATA_DIR_NAME = "test_data"
LOGS_DIR_NAME = "fixtures"
MIGRATIONS_DIR_NAME = "migrations"
"""
CONSTANT ENVIRONMENT NAMES
"""
PROD_ENV_NAME = "prod"
STAGE_ENV_NAME = "stage"
TEST_ENV_NAME = "test"
DEV_ENV_NAME = "dev"
LOCAL_ENV_NAME = "local"

ENV_NAME_LIST = [LOCAL_ENV_NAME, DEV_ENV_NAME, TEST_ENV_NAME, STAGE_ENV_NAME, PROD_ENV_NAME]
DEV_OR_TEST_ENV_NAMES_LIST = [LOCAL_ENV_NAME, DEV_ENV_NAME, TEST_ENV_NAME]
"""
CONSTANT FILE NAMES
"""
PROD_ENV_FILE_NAME = ".env"
DEV_ENV_FILE_NAME = ".env.local"

"""
CONSTANT DATABASE NAMES
"""
DEFAULT_DATABASE_NAME = "default"
LOGS_DATABASE_NAME = "logs"

YAML_FILE_EXTENTION_NAME = "yaml"